==> mongodb-6.0.27.gh.tar.gz: mongo-r6.0.27/src/mongo/db/matcher/match_expression_util_test.cpp <==
/**
 *    Copyright (C) 2020-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#include "mongo/platform/basic.h"

#include "mongo/db/matcher/match_expression_util.h"

#include "mongo/unittest/unittest.h"

namespace mongo::match_expression_util {
namespace {
TEST(BSONObjIteratorUtils, AdvanceBy) {
    auto obj = BSON("a" << 1 << "b" << 2 << "c" << 3);
    BSONObjIterator iter = BSONObjIterator(obj);
    advanceBy(0, iter);
    ASSERT_TRUE(iter.more());
    ASSERT_EQUALS(iter.next().fieldNameStringData(), "a");
    advanceBy(1, iter);
    ASSERT_TRUE(iter.more());
    ASSERT_EQUALS(iter.next().fieldNameStringData(), "c");
    ASSERT_FALSE(iter.more());
    advanceBy(0, iter);
    ASSERT_FALSE(iter.more());
    advanceBy(1, iter);
    ASSERT_FALSE(iter.more());
}
}  // namespace
}  // namespace mongo::match_expression_util

==> mongodb-8.0.8.gh.tar.gz: mongo-r8.0.8/src/mongo/db/matcher/match_expression_util_test.cpp <==
/**
 *    Copyright (C) 2020-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#include <memory>

#include "mongo/base/string_data.h"
#include "mongo/bson/bsonelement.h"
#include "mongo/bson/bsonmisc.h"
#include "mongo/bson/bsonobjbuilder.h"
#include "mongo/db/matcher/match_expression_util.h"
#include "mongo/unittest/assert.h"
#include "mongo/unittest/framework.h"

namespace mongo::match_expression_util {
namespace {
TEST(BSONObjIteratorUtils, AdvanceBy) {
    auto obj = BSON("a" << 1 << "b" << 2 << "c" << 3);
    BSONObjIterator iter = BSONObjIterator(obj);
    advanceBy(0, iter);
    ASSERT_TRUE(iter.more());
    ASSERT_EQUALS(iter.next().fieldNameStringData(), "a");
    advanceBy(1, iter);
    ASSERT_TRUE(iter.more());
    ASSERT_EQUALS(iter.next().fieldNameStringData(), "c");
    ASSERT_FALSE(iter.more());
    advanceBy(0, iter);
    ASSERT_FALSE(iter.more());
    advanceBy(1, iter);
    ASSERT_FALSE(iter.more());
}
}  // namespace
}  // namespace mongo::match_expression_util
